﻿using System;
using System.Collections.Generic;
using System.Windows;

namespace SpiderWeb.Controls
{
	public class TreeLayout : ILayout
	{
		public Dictionary<SpiderWebItem, Point> LayoutPositions { get; private set; }
		public double Radius { get; set; }

		public void Apply(Rect layoutRect, SpiderWebItem rootItem)
		{
			var center = new Point(layoutRect.Width / 2, layoutRect.Height / 2);

			LayoutPositions = new Dictionary<SpiderWebItem, Point>();

			PositionItem(rootItem, center, 1);
		}

		private void PositionItem(SpiderWebItem parent, Point position, int level)
		{
			LayoutPositions[parent] = position;

			// Children
			if (parent.HasChildren)
			{
				var deltaAngle = Math.PI * 2 / parent.ChildItems.Count;
				int index = 0;
				var radius = 200;
				foreach (var item in parent.ChildItems)
				{
					var levelRadius = (item.HasChildren) ? (level + 1) * radius : radius;
					var x = position.X + levelRadius * Math.Cos(deltaAngle * index);
					var y = position.Y + levelRadius * Math.Sin(deltaAngle * index);

					PositionItem(item, new Point(x, y), level + 1);
					index++;
				}
			}
		}

	}
}