﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using SpiderWeb.Controls;

namespace SpiderWebDemo
{
	public partial class MainPage : UserControl
	{
		private NodeViewModel _dataSource;
		private TreeLayout _treeLayout = new TreeLayout();

		public MainPage()
		{
			InitializeComponent();

			_dataSource = new NodeViewModel()
											{
												Title = "Leader",
												Children = new ObservableCollection<NodeViewModel>
			                            	                            	{
			                            	                            		new NodeViewModel{ 
																					Title = "Sunshine Systems", 
																					Children = new ObservableCollection<NodeViewModel>
																				           	{
			                            	                            		new NodeViewModel{ Title = "Time"},
			                            	                            		new NodeViewModel{ Title = "Space"},
			                            	                            		new NodeViewModel{ Title = "Motion"},
			                            	                            		new NodeViewModel{ Title = "Energy"},
																				           	}},
			                            	                            		new NodeViewModel{ Title = "Strength"},
			                            	                            		new NodeViewModel{ Title = "Comps"},
			                            	                            		new NodeViewModel{ Title = "Import"},
			                            	                            		new NodeViewModel{ Title = "Mobile"},
			                            	                            	}
											};

			AssociateParents(_dataSource);
			DataContext = _dataSource;

		}

		private void AssociateParents(NodeViewModel parent)
		{
			if (parent.Children == null) return;

			foreach (var child in parent.Children)
			{
				child.Parent = parent;
				AssociateParents(child);
			}
		}

		private void DoLayout(object sender, RoutedEventArgs e)
		{
			SpiderControl.ApplyLayout(_treeLayout);
		}
	}

	public class NodeViewModel : INotifyPropertyChanged
	{
		private string _title;

		public string Title
		{
			get { return _title; }
			set
			{
				_title = value;
				NotifyChange("Title");
			}
		}

		public ObservableCollection<NodeViewModel> Children
		{
			get { return _children; }
			set
			{
				_children = value;
				NotifyChange("Children");
			}
		}

		private void NotifyChange(string propName)
		{
			if (PropertyChanged != null)
				PropertyChanged(this, new PropertyChangedEventArgs(propName));
		}

		public NodeViewModel Parent { get; set; }

		private ObservableCollection<NodeViewModel> _children;
		public event PropertyChangedEventHandler PropertyChanged;
	}
}
